summaryrefslogtreecommitdiff
path: root/pkg/machine/qemu/config.go
diff options
context:
space:
mode:
authorDaniel J Walsh <dwalsh@redhat.com>2022-04-21 17:03:45 -0400
committerDaniel J Walsh <dwalsh@redhat.com>2022-04-21 17:05:16 -0400
commitcc3790f332d989440eb1720e24e3619fc97c74ee (patch)
treef3861d4c3d17a7e9d0291a6f3288d6f9a411e373 /pkg/machine/qemu/config.go
parentbdbd477c286b8bcf27a498d0f8b0e8ba7642a018 (diff)
downloadpodman-cc3790f332d989440eb1720e24e3619fc97c74ee.tar.gz
podman-cc3790f332d989440eb1720e24e3619fc97c74ee.tar.bz2
podman-cc3790f332d989440eb1720e24e3619fc97c74ee.zip
Switch all rootful to rootfull
We are inconsistent on the name, we should stick with rootfull. [NO NEW TESTS NEEDED] Existing tests should handle this and no tests for machines exists yet. Signed-off-by: Daniel J Walsh <dwalsh@redhat.com>
Diffstat (limited to 'pkg/machine/qemu/config.go')
-rw-r--r--pkg/machine/qemu/config.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkg/machine/qemu/config.go b/pkg/machine/qemu/config.go
index 4d4e3a6c1..6ab25b951 100644
--- a/pkg/machine/qemu/config.go
+++ b/pkg/machine/qemu/config.go
@@ -57,8 +57,8 @@ type MachineVMV1 struct {
QMPMonitor Monitorv1
// RemoteUsername of the vm user
RemoteUsername string
- // Whether this machine should run in a rootful or rootless manner
- Rootful bool
+ // Whether this machine should run in a rootfull or rootless manner
+ Rootfull bool
// UID is the numerical id of the user that called machine
UID int
}
@@ -99,8 +99,8 @@ type ImageConfig struct {
// HostUser describes the host user
type HostUser struct {
- // Whether this machine should run in a rootful or rootless manner
- Rootful bool
+ // Whether this machine should run in a rootfull or rootless manner
+ Rootfull bool
// UID is the numerical id of the user that called machine
UID int
}